# @(#)20  1.5 src/cmdline/staging/scripts/generate_import_properties.py, amws.cmdline, fim611, 060808b 5/11/06 19:17:08
# (C) Copyright International Business Machines Corporation 2005. All rights
# reserved.  U.S. Government Users Restricted Rights -- Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 
from fim_base import read_properties_file, prepare_mgr_objs, get_domain_instance, FIM_TRUE, FIM_FALSE
from fed_utils import get_federation, get_federations, get_federation_properties
from fed_utils import get_partner, get_partners
from com.tivoli.am.fim.logging import FIMLoggerFactory
from com.tivoli.am.fim.logging import FIMLogger
from com.tivoli.am.fim.logging import FIMLevel
from com.tivoli.am.fim.i18n.msgs import CmdLineMessages
from jarray import array
from java.lang import Object
from com.tivoli.am.fim.logging import FIMLoggerConstants
from com.tivoli.am.fim.middlemanager.ssps import FederationManager
import sys
from domain_utils import delete_domain, create_domain, import_configuration_archive

# Set up FIMLogger
component_name = "StagingTools"
script_name = "generate_import_properties.py"
method_name = script_name
class_name = "com.tivoli.am.fim.cmdline." + script_name[0:-3]
FIMLoggerFactory.enableStdout(FIMLevel.ALL)
FIMLoggerFactory.setPreferredFIMLoggerImpl(FIMLoggerConstants.FIMLOGGER_BASE_IMPL)
log = FIMLoggerFactory.getFIMLogger(component_name, class_name, CmdLineMessages.CLASS_NAME)
import_props_filename = "_import.properties"
unix_slash = "/"
win_slash = "\\"

# Creates a properties file for federations
def write_fed_props(fed, filename):
    role = fed.getSelfRoleStr()
    protocol = fed.getSSOProtocolStr()
    fh = open(filename,"w")
    fh.write("# This file was generated by generate_import_properties.py.\n")
    fh.write("# It contains properties used by the import_federations_and_partners.py \n")
    fh.write("# script to import a federation with the properties specified here. \n")
    fh.write("# This properties file is applicable to the following federation type: \n")
    fh.write("#     Role = %s \n"%role)
    fh.write("#     Protocol = %s \n"%protocol)
    fh.write("# \n")

    fed_props = get_federation_properties(fed)
    for p in fed_props.keys():
        fh.write("#%s=%s\n"%(p, fed_props[p]))
    fh.close()
    
# Creates a properties file for partners
def write_partner_props(fed, partner, filename):
    role = fed.getSelfRoleStr()
    protocol = fed.getSSOProtocolStr()
    fh = open(filename,"w")
    fh.write("# This file was generated by generate_import_properties.py.\n")
    fh.write("# It contains properties used by the import_federations_and_partners.py \n")
    fh.write("# script to import a partner with the properties specified here. \n")
    fh.write("# This properties file is applicable to the following federation type: \n")
    fh.write("#     Role = %s \n"%role)
    fh.write("#     Protocol = %s \n"%protocol)
    fh.write("# \n")

    fed_props = get_federation_properties(fed, partner)
    for p in fed_props.keys():
        fh.write("#%s=%s\n"%(p, fed_props[p]))
    fh.close()

def usage():
    inserts = array([script_name], Object)
    log.logMessage(FIMLevel.INFO, method_name, \
        CmdLineMessages.usage_generate_import_properties, inserts)
    raise SystemExit

if __name__ == 'main':

    if len(sys.argv) < 2 or len(sys.argv) > 3:
        usage()
    
    isEmpty = FIM_FALSE
    createTempDomain = FIM_FALSE

    src_props_file = sys.argv[0]
    properties_directory = sys.argv[1]
    
    # In this case, either the no properties are needed or the staging domain will be
    # created and loaded with the configuration in the supplied FIM archive jar file
    if len(sys.argv) == 3:   
        if sys.argv[2]=="-no_properties":
            isEmpty = FIM_TRUE
            empty_properties = "empty.properties"
            fh = open(properties_directory + unix_slash + empty_properties,"w")
            fh.write("# This file represents an empty FIM staging properties file.\n")
            fh.write("# It is used by the import_federations_and_partners.py script.\n")
            fh.close()
        elif sys.argv[2].find(".jar") > 0:
            createTempDomain = FIM_TRUE
            archive_file = sys.argv[2]
        else:
            usage()

    import_props_file = properties_directory + unix_slash + import_props_filename

    # Get the source federation manager
    src_props = read_properties_file(src_props_file)

    # If createTempDomain is false, then it is assumed the staging domain
    # exists and has federations in it.
    if createTempDomain:
        domain = get_domain_instance(src_props)
        delete_domain(domain)
        create_domain(domain)
        import_configuration_archive(domain, archive_file)

    (src_fed_mgr, src_sec_tok_mgr) = prepare_mgr_objs(src_props, \
        "generate_import_properties")    

    fed_list = get_federations(src_fed_mgr).values()
    if not fed_list:
        inserts = array([src_props["Domain"]], Object)
        log.logMessage(FIMLevel.INFO, method_name, \
            CmdLineMessages.no_federations_exist_for_this_domain, inserts)
        raise SystemExit
        
    fh = open(import_props_file,"w")
    fh.write("# This file was generated by generate_import_properties.py.\n")
    fh.write("# It contains properties used by the import_federations_and_partners.py \n")
    fh.write("# script to import federations and properties with the values\n")
    fh.write("# specified here. The sytax for assigning properties here is:\n")
    fh.write("# federation_name=['federation_properties_file', \n")
    fh.write("#    { 'partner_name1':'partner_properties_file1', ..., \n")
    fh.write("#      'partner_nameN':'partner_properties_fileN'}]\n")

    for fed_name in fed_list:
        src_fed = src_fed_mgr.getFederationByDisplayName(fed_name, src_sec_tok_mgr)
        partner_names = get_partners(src_fed).values()

        if isEmpty:
            # this option is useful when imported many federations without
            # making any property changes.  Only one properties file called
            # empty.properties is needed.
            fed_file_name = empty_properties
            partner_file_list = map(lambda p: (p, empty_properties), partner_names)
        else:   
            fed_file_name = "".join(fed_name.split(" ")) + ".properties" # remove spaces from names
            write_fed_props(src_fed, properties_directory + unix_slash + fed_file_name)
            # creates a list of (partner, partner.properties) tuples   
            partner_file_list = map(lambda p: (p, p + ".properties"), partner_names)
       
        
        p_dict={}
        for p, f in partner_file_list:
            f_name = "".join(f.split(" ")) # remove spaces from file names
            f_name = "".join(f_name.split(":")) # remove colon from file names
            f_name = f_name.replace("/","_") # replace slashes with underscores
            p_dict[p]=f_name      
            if not isEmpty: 
                src_partner = get_partner(src_fed, p)
                partner_props = get_federation_properties(src_fed, src_partner) 
                write_partner_props(src_fed, src_partner, \
                    properties_directory + unix_slash + f_name) 
        # write the property to the file
        fh.write("%s=['%s',%s]\n"%(fed_name, fed_file_name, str(p_dict)))
    fh.close()
  
    raise SystemExit
    